==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RuleGroupFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RuleGroupFluent<A extends RuleGroupFluent<A>> extends Fluent<A>{
  public String getInterval();
  public A withInterval(String interval);
  public Boolean hasInterval();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getPartialResponseStrategy();
  public A withPartialResponseStrategy(String partialResponseStrategy);
  public Boolean hasPartialResponseStrategy();
  public A addToRules(Integer index,Rule item);
  public A setToRules(Integer index,Rule item);
  public A addToRules(io.fabric8.openshift.api.model.monitoring.v1.Rule... items);
  public A addAllToRules(Collection<Rule> items);
  public A removeFromRules(io.fabric8.openshift.api.model.monitoring.v1.Rule... items);
  public A removeAllFromRules(Collection<Rule> items);
  public A removeMatchingFromRules(Predicate<RuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Rule> getRules();
  public List<Rule> buildRules();
  public Rule buildRule(Integer index);
  public Rule buildFirstRule();
  public Rule buildLastRule();
  public Rule buildMatchingRule(Predicate<RuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<RuleBuilder> predicate);
  public A withRules(List<Rule> rules);
  public A withRules(io.fabric8.openshift.api.model.monitoring.v1.Rule... rules);
  public Boolean hasRules();
  public RuleGroupFluent.RulesNested<A> addNewRule();
  public RuleGroupFluent.RulesNested<A> addNewRuleLike(Rule item);
  public RuleGroupFluent.RulesNested<A> setNewRuleLike(Integer index,Rule item);
  public RuleGroupFluent.RulesNested<A> editRule(Integer index);
  public RuleGroupFluent.RulesNested<A> editFirstRule();
  public RuleGroupFluent.RulesNested<A> editLastRule();
  public RuleGroupFluent.RulesNested<A> editMatchingRule(Predicate<RuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface RulesNested<N> extends Nested<N>,RuleFluent<RuleGroupFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}

==> openshift-model-monitoring-6.7.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/RuleGroupFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RuleGroupFluent<A extends RuleGroupFluent<A>> extends Fluent<A>{
  public String getInterval();
  public A withInterval(String interval);
  public Boolean hasInterval();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getPartialResponseStrategy();
  public A withPartialResponseStrategy(String partialResponseStrategy);
  public Boolean hasPartialResponseStrategy();
  public A addToRules(int index,Rule item);
  public A setToRules(int index,Rule item);
  public A addToRules(io.fabric8.openshift.api.model.monitoring.v1.Rule... items);
  public A addAllToRules(Collection<Rule> items);
  public A removeFromRules(io.fabric8.openshift.api.model.monitoring.v1.Rule... items);
  public A removeAllFromRules(Collection<Rule> items);
  public A removeMatchingFromRules(Predicate<RuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Rule> getRules();
  public List<Rule> buildRules();
  public Rule buildRule(int index);
  public Rule buildFirstRule();
  public Rule buildLastRule();
  public Rule buildMatchingRule(Predicate<RuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<RuleBuilder> predicate);
  public A withRules(List<Rule> rules);
  public A withRules(io.fabric8.openshift.api.model.monitoring.v1.Rule... rules);
  public Boolean hasRules();
  public RuleGroupFluent.RulesNested<A> addNewRule();
  public RuleGroupFluent.RulesNested<A> addNewRuleLike(Rule item);
  public RuleGroupFluent.RulesNested<A> setNewRuleLike(int index,Rule item);
  public RuleGroupFluent.RulesNested<A> editRule(int index);
  public RuleGroupFluent.RulesNested<A> editFirstRule();
  public RuleGroupFluent.RulesNested<A> editLastRule();
  public RuleGroupFluent.RulesNested<A> editMatchingRule(Predicate<RuleBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface RulesNested<N> extends Nested<N>,RuleFluent<RuleGroupFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}
